``pants.stream``
****************

.. automodule:: pants.stream


``Stream``
==========

.. autoclass:: Stream
    :members: remote_address, local_address, read_delimiter, buffer_size,
        startSSL, connect, close, write, write_file, write_packed, flush,
        on_read, on_write, on_connect, on_ssl_handshake, on_close
